@@ -16,6 +16,12 @@ pub struct Command {
     #[cfg(feature = "clippy")]
     #[clap(long, default_value = "clippy.json")]
     pub clippy_path: PathBuf,
+    #[cfg(feature = "deny")]
+    #[clap(short, long)]
+    pub deny: bool,
+    #[cfg(feature = "deny")]
+    #[clap(long, default_value = "deny.json")]
+    pub deny_path: PathBuf,
     #[clap(short, long, default_value = "sonar.json")]
     pub sonar_path: PathBuf,
 }
