@@ -3,7 +3,7 @@ use cargo_metadata::{
     diagnostic::{DiagnosticLevel, DiagnosticSpan},
     Message,
 };
-use eyre::Context;
+use eyre::Context as _;
 use skip_error::SkipError as _;
 use std::{
     fs::File,
@@ -63,7 +63,8 @@ impl TryFrom<Message> for sonar::Issue {
                 .message
                 .code
                 .as_ref()
-                .map(|diagnostic_code| diagnostic_code.code.clone());
+                .map(|diagnostic_code| diagnostic_code.code.clone())
+                .unwrap_or_else(|| String::from("clippy"));
             let severity = sonar::Severity::from(&message.message.level);
             let r#type = sonar::IssueType::CodeSmell;
             let (primary_location, secondary_locations) = match message.message.spans.len() {
