@@ -7,6 +7,8 @@ mod cargo;
 mod cli;
 #[cfg(feature = "clippy")]
 mod clippy;
+#[cfg(feature = "deny")]
+mod deny;
 mod sonar;
 
 use std::fs::File;
@@ -59,6 +61,12 @@ fn main() -> Result<()> {
         let clippy_report: sonar::Report = Clippy::new(options.clippy_path).try_into()?;
         sonar_report.extend(clippy_report);
     }
+    #[cfg(feature = "deny")]
+    if options.deny {
+        use crate::deny::Deny;
+        let deny_report: sonar::Report = Deny::new(options.deny_path, &lockfile).try_into()?;
+        sonar_report.extend(deny_report);
+    }
     let file = File::create(options.sonar_path).context("failed to create 'sonar.json' file")?;
     info!("{} sonar issues created", sonar_report.len());
     #[cfg(not(debug_assertions))]
